<!-- TITLE: Hackingtools Py -->
<!-- SUBTITLE: A quick summary of Hackingtools Py -->

# Instalación
Nos tenemos que posicionar en el directorio donde esté 'hackingtools. py' para poder instalar los 'requirements'.

Para ello se recomienda además de trabajar con Anaconda, hacer un entorno virtual para este proyecto.

Creamos un entorno en Anaconda:

**conda create -n nombreEntornoQueQuierasPoner python==3.7.2**

Es importante que la versión de Python sea la 3.7.2.

Una vez hecho esto:

**pip install -r requirements.txt**